# COMPAS RBE

Rigid Block Equilibrium Analysis for the COMPAS framework

## Getting Started

<https://blockresearchgroup.github.io/compas_rbe/gettingstarted.html>

## First Steps

## Issues

## Contact

## License
